@@ -188,13 +188,13 @@ test_that("additional wb tests", {
   wb1 <- wb_load(xlsxFile)
 
   # showFormula
-  exp <- data.frame(Var7 = "1/0", row.names = "2")
+  exp <- data.frame(Var7 = "1/0", row.names = "2", stringsAsFactors = FALSE)
   got <- wb_to_df(wb1, showFormula = TRUE, rows = 1:2, cols = 8)
   expect_equal(exp, got, ignore_attr = TRUE)
   expect_equal(names(exp), names(got))
 
   # detectDates
-  exp <- data.frame(Var5 = as.Date("2015-02-07"), row.names = "2")
+  exp <- data.frame(Var5 = as.Date("2015-02-07"), row.names = "2", stringsAsFactors = FALSE)
   got <- wb_to_df(wb1, showFormula = TRUE, rows = 1:2, cols = 6)
   expect_equal(exp, got, ignore_attr = TRUE)
   expect_equal(names(exp), names(got))
@@ -202,7 +202,8 @@ test_that("additional wb tests", {
   # types
   # Var1 is requested as character
   exp <- data.frame(Var1 = c("TRUE", "TRUE", "TRUE", "FALSE"),
-                    Var3 = c(1.00, NaN, 1.34, NA))
+                    Var3 = c(1.00, NaN, 1.34, NA),
+                    stringsAsFactors = FALSE)
   got <- wb_to_df(wb1, cols = c(1, 4),
                   types = c("Var1" = 0, "Var3" = 1))[seq_len(4), ]
   expect_equal(exp, got, ignore_attr = TRUE)
@@ -439,6 +440,46 @@ test_that("Loading a workbook with property preserves it.", {
 
   wb2$set_properties(company = "ggg")
   expect_equal(wb2$get_properties()[["company"]], "ggg")
+
+  wb <- wb_workbook() %>%
+    wb_add_worksheet() %>%
+    wb_set_properties(
+      custom = list(
+        Software    = "openxlsx2",
+        Version     = 1.5,
+        ReleaseDate = as.Date("2024-03-26"),
+        CRAN        = TRUE
+      )
+    )
+
+  exp <- "<Properties xmlns=\"http://schemas.openxmlformats.org/officeDocument/2006/custom-properties\" xmlns:vt=\"http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes\"><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"2\" name=\"Software\"><vt:lpwstr>openxlsx2</vt:lpwstr></property><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"3\" name=\"Version\"><vt:r8>1.5</vt:r8></property><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"4\" name=\"ReleaseDate\"><vt:filetime>2024-03-26T00:00:00Z</vt:filetime></property><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"5\" name=\"CRAN\"><vt:bool>1</vt:bool></property></Properties>"
+  got <- wb$custom
+  expect_equal(exp, got)
+
+  wb <- wb %>% wb_set_properties(
+    custom = list(
+      Software    = "openxlsx2",
+      Version     = "1.5.0.9000",
+      ReleaseDate = as.Date("2024-03-31"),
+      CRAN        = FALSE,
+      DEV         = TRUE
+    )
+  )
+
+  exp <- "<Properties xmlns=\"http://schemas.openxmlformats.org/officeDocument/2006/custom-properties\" xmlns:vt=\"http://schemas.openxmlformats.org/officeDocument/2006/docPropsVTypes\"><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"2\" name=\"Software\"><vt:lpwstr>openxlsx2</vt:lpwstr></property><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"3\" name=\"Version\"><vt:lpwstr>1.5.0.9000</vt:lpwstr></property><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"4\" name=\"ReleaseDate\"><vt:filetime>2024-03-31T00:00:00Z</vt:filetime></property><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"5\" name=\"CRAN\"><vt:bool>0</vt:bool></property><property fmtid=\"{D5CDD505-2E9C-101B-9397-08002B2CF9AE}\" pid=\"6\" name=\"DEV\"><vt:bool>1</vt:bool></property></Properties>"
+  got <- wb$custom
+  expect_equal(exp, got)
+
+})
+
+test_that("Creation time is not changed by set_property unless specified", {
+  op <- options("openxlsx2.datetimeCreated" = NULL)
+  on.exit(options(op), add = TRUE)
+  t1 <- "2000-01-01T00:00:00Z"
+  wb <- wb_workbook(datetime_created = as.POSIXct(t1, tz = "UTC"))
+  wb$set_properties()
+  t2 <- wb$get_properties()[["datetime_created"]]
+  expect_equal(t1, t2)
 })
 
 test_that("failing to unzip works as expected", {
@@ -460,3 +501,10 @@ test_that("failing to unzip works as expected", {
   expect_error(wb <- wb_load(tmp_zip), "File does not appear to be xlsx, xlsm or xlsb")
 
 })
+
+test_that("file with [trash] folder works", {
+
+  fl <- testfile_path("trash_folder.xlsx")
+  expect_silent(wb <- wb_load(fl))
+
+})
