@@ -160,7 +160,8 @@ test_that("reading with pre defined types works", {
     integer = sample(1:5, 5, TRUE),
     date = Sys.Date() - 0:4,
     datetime = Sys.time() - 0:4,
-    character = letters[1:5]
+    character = letters[1:5],
+    stringsAsFactors = FALSE
   )
 
   wb <- wb_workbook()$add_worksheet()$add_data(x = dat)
@@ -192,7 +193,8 @@ test_that("column names are not missing with col_names = FALSE", {
   dat <- data.frame(
     numeric = 1:2,
     character = c("a", "b"),
-    logical = c(TRUE, FALSE)
+    logical = c(TRUE, FALSE),
+    stringsAsFactors = FALSE
   )
 
   wb <- wb_workbook()$add_worksheet()$add_data(x = dat)
