@@ -257,7 +257,7 @@ test_that("test add_cell_style()", {
   expect_equal(exp, got)
 
   ###
-  exp <- "<xf applyAlignment=\"1\" applyBorder=\"1\" applyFill=\"1\" applyFont=\"1\" applyNumberFormat=\"1\" applyProtection=\"1\" borderId=\"1\" fillId=\"1\" fontId=\"1\" numFmtId=\"1\" pivotButton=\"0\" quotePrefix=\"0\" xfId=\"1\"><alignment horizontal=\"1\" indent=\"1\" justifyLastLine=\"1\" readingOrder=\"1\" relativeIndent=\"1\" shrinkToFit=\"1\" textRotation=\"1\" vertical=\"1\" wrapText=\"1\"/><extLst extLst=\"1\"/><protection hidden=\"1\" locked=\"1\"/></xf>"
+  exp <- "<xf applyAlignment=\"1\" applyBorder=\"1\" applyFill=\"1\" applyFont=\"1\" applyNumberFormat=\"1\" applyProtection=\"1\" borderId=\"1\" fillId=\"1\" fontId=\"1\" numFmtId=\"1\" pivotButton=\"0\" quotePrefix=\"0\" xfId=\"1\"><alignment horizontal=\"1\" indent=\"1\" justifyLastLine=\"1\" readingOrder=\"1\" relativeIndent=\"1\" shrinkToFit=\"1\" textRotation=\"1\" vertical=\"1\" wrapText=\"1\"/><protection hidden=\"1\" locked=\"1\"/><extLst><ext><foo/></ext></extLst></xf>"
   got <- create_cell_style(
     borderId = "1",
     fillId = "1",
@@ -275,7 +275,7 @@ test_that("test add_cell_style()", {
     textRotation = "1",
     vertical = "1",
     wrapText = "1",
-    extLst = "1",
+    extLst = "<extLst><ext><foo/></ext></extLst>",
     hidden = "1",
     locked = "1"
   )
@@ -480,7 +480,8 @@ test_that("add numfmt is no longer slow", {
   out <- data.frame(
     date = dat,
     chr  = as.character(dat),
-    num  = seq_along(dat) - 1
+    num  = seq_along(dat) - 1,
+    stringsAsFactors = FALSE
   )
 
   wb <- wb_workbook() %>%
@@ -852,7 +853,8 @@ test_that("apply styles across columns and rows", {
   exp <- data.frame(
     customFormat = c("1", "1"),
     r = c("3", "4"),
-    s = c("1", "1")
+    s = c("1", "1"),
+    stringsAsFactors = FALSE
   )
   got <- wb$worksheets[[1]]$sheet_data$row_attr[c("customFormat", "r", "s")]
   expect_equal(exp, got)
@@ -872,6 +874,8 @@ test_that("apply styles across columns and rows", {
 
 test_that("create_colors_xml() works", {
 
+  skip_if(grDevices::palette()[2] == "red") # R 3.6 has a different palette
+
   exp <- "<a:clrScheme name=\"Base R\"><a:dk1><a:sysClr val=\"windowText\" lastClr=\"000000\"/></a:dk1><a:lt1><a:sysClr val=\"window\" lastClr=\"FFFFFF\"/></a:lt1><a:dk2><a:srgbClr val=\"00008B\"/></a:dk2><a:lt2><a:srgbClr val=\"D3D3D3\"/></a:lt2><a:accent1><a:srgbClr val=\"DF536B\"/></a:accent1><a:accent2><a:srgbClr val=\"61D04F\"/></a:accent2><a:accent3><a:srgbClr val=\"2297E6\"/></a:accent3><a:accent4><a:srgbClr val=\"28E2E5\"/></a:accent4><a:accent5><a:srgbClr val=\"CD0BBC\"/></a:accent5><a:accent6><a:srgbClr val=\"F5C710\"/></a:accent6><a:hlink><a:srgbClr val=\"0000FF\"/></a:hlink><a:folHlink><a:srgbClr val=\"A020F0\"/></a:folHlink></a:clrScheme>"
   got <- create_colors_xml()
   expect_equal(exp, got)
@@ -888,3 +892,27 @@ test_that("create_colors_xml() works", {
   expect_equal(exp, got)
 
 })
+
+test_that("dims work", {
+
+  wb <- wb_workbook()$add_worksheet()
+
+  new_fill <- create_fill(patternType = "solid", fgColor = wb_color(hex = "FF334E6F"))
+  wb$styles_mgr$add(new_fill, "new_fill")
+
+  xf <- create_cell_style(fill_id = wb$styles_mgr$get_fill_id("new_fill"))
+  wb$styles_mgr$add(xf, "xf")
+
+  wb$set_cell_style(
+    dims = "A1:A2",
+    style = wb$styles_mgr$get_xf_id("xf")
+  )
+
+  wb$set_cell_style(
+    dims = c("B1", "B2"),
+    style = wb$styles_mgr$get_xf_id("xf")
+  )
+
+  expect_setequal(wb$worksheets[[1]]$sheet_data$cc$c_s, "1")
+
+})
