@@ -35,7 +35,8 @@ test_that("Writing mixed EDT/EST Posixct with write_data & write_datatable", {
 
   df <- data.frame(
     timeval = c(TimeDT1, TimeDT2),
-    timetxt = format(c(TimeDT1, TimeDT2), "%Y-%m-%d %H:%M")
+    timetxt = format(c(TimeDT1, TimeDT2), "%Y-%m-%d %H:%M"),
+    stringsAsFactors = FALSE
   )
 
   wb <- wb_workbook()
@@ -81,7 +82,8 @@ test_that("numfmt escaping works", {
 
   test_data <- data.frame(
     datetime_col = as.POSIXct("2023-12-31 00:00:00"),
-    date_col = as.Date("2023-12-31")
+    date_col = as.Date("2023-12-31"),
+    stringsAsFactors = FALSE
   )
   wb <- wb_workbook()$add_worksheet()$add_data(x = test_data)
 
